Struct Iter

struct Iter<'a, T> { ... }

HeaderMap entry iterator.

Yields (&HeaderName, &value) tuples. The same header name may be yielded more than once if it has more than one associated value.

Implementations

impl<'a, T> Freeze for Iter<'a, T>

impl<'a, T> FusedIterator for Iter<'a, T>

impl<'a, T> Iterator for Iter<'a, T>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<'a, T> RefUnwindSafe for Iter<'a, T>

impl<'a, T> Unpin for Iter<'a, T>

impl<'a, T> UnsafeUnpin for Iter<'a, T>

impl<'a, T> UnwindSafe for Iter<'a, T>

impl<'a, T: $crate::fmt::Debug> Debug for Iter<'a, T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, T: Sync> Send for Iter<'a, T>

impl<'a, T: Sync> Sync for Iter<'a, T>

impl<I> IntoIterator for Iter<'a, T>

fn into_iter(self: Self) -> I

impl<T> Any for Iter<'a, T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Iter<'a, T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Iter<'a, T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Iter<'a, T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Iter<'a, T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Iter<'a, T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Iter<'a, T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>