Struct ValueDrain

struct ValueDrain<'a, T> { ... }

An drain iterator of all values associated with a single header name.

Implementations

impl<'a, T> Drop for ValueDrain<'a, T>

fn drop(self: &mut Self)

impl<'a, T> Freeze for ValueDrain<'a, T>

impl<'a, T> FusedIterator for ValueDrain<'a, T>

impl<'a, T> Iterator for ValueDrain<'a, T>

fn next(self: &mut Self) -> Option<T>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<'a, T> RefUnwindSafe for ValueDrain<'a, T>

impl<'a, T> Unpin for ValueDrain<'a, T>

impl<'a, T> UnsafeUnpin for ValueDrain<'a, T>

impl<'a, T> UnwindSafe for ValueDrain<'a, T>

impl<'a, T: $crate::fmt::Debug> Debug for ValueDrain<'a, T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, T: Send> Send for ValueDrain<'a, T>

impl<'a, T: Sync> Sync for ValueDrain<'a, T>

impl<I> IntoIterator for ValueDrain<'a, T>

fn into_iter(self: Self) -> I

impl<T> Any for ValueDrain<'a, T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ValueDrain<'a, T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ValueDrain<'a, T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ValueDrain<'a, T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for ValueDrain<'a, T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ValueDrain<'a, T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ValueDrain<'a, T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>