Struct ValueIterMut
struct ValueIterMut<'a, T> { ... }
A mutable iterator of all values associated with a single header name.
Implementations
impl<'a, T> Freeze for ValueIterMut<'a, T>
impl<'a, T> FusedIterator for ValueIterMut<'a, T>
impl<'a, T> RefUnwindSafe for ValueIterMut<'a, T>
impl<'a, T> Unpin for ValueIterMut<'a, T>
impl<'a, T> UnsafeUnpin for ValueIterMut<'a, T>
impl<'a, T> UnwindSafe for ValueIterMut<'a, T>
impl<'a, T: $crate::fmt::Debug> Debug for ValueIterMut<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, T: 'a> DoubleEndedIterator for ValueIterMut<'a, T>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>
impl<'a, T: 'a> Iterator for ValueIterMut<'a, T>
fn next(self: &mut Self) -> Option<<Self as >::Item>
impl<'a, T: Send> Send for ValueIterMut<'a, T>
impl<'a, T: Sync> Sync for ValueIterMut<'a, T>
impl<I> IntoIterator for ValueIterMut<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for ValueIterMut<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ValueIterMut<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ValueIterMut<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ValueIterMut<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ValueIterMut<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ValueIterMut<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ValueIterMut<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>