Enum Entry
enum Entry<'a, T: 'a>
A view into a single location in a HeaderMap, which may be vacant or occupied.
Variants
-
Occupied(OccupiedEntry<'a, T>) An occupied entry
-
Vacant(VacantEntry<'a, T>) A vacant entry
Implementations
impl<'a, T> Entry<'a, T>
fn or_insert(self: Self, default: T) -> &'a mut TEnsures a value is in the entry by inserting the default if empty.
Returns a mutable reference to the first value in the entry.
Panics
This method panics if capacity exceeds max
HeaderMapcapacityExamples
# use HeaderMap; let mut map: = default; let headers = &; for &header in headers assert_eq!; assert_eq!;fn or_try_insert(self: Self, default: T) -> Result<&'a mut T, MaxSizeReached>Ensures a value is in the entry by inserting the default if empty.
Returns a mutable reference to the first value in the entry.
Errors
This function may return an error if
HeaderMapexceeds max capacityExamples
# use HeaderMap; let mut map: = default; let headers = &; for &header in headers assert_eq!; assert_eq!;fn or_insert_with<F: FnOnce() -> T>(self: Self, default: F) -> &'a mut TEnsures a value is in the entry by inserting the result of the default function if empty.
The default function is not called if the entry exists in the map. Returns a mutable reference to the first value in the entry.
Examples
Basic usage.
# use HeaderMap; let mut map = new; let res = map.entry .or_insert_with; assert_eq!;The default function is not called if the entry exists in the map.
# use HeaderMap; # use HOST; let mut map = new; map.try_insert.unwrap; let res = map.try_entry .unwrap .or_try_insert_with .unwrap; assert_eq!;fn or_try_insert_with<F: FnOnce() -> T>(self: Self, default: F) -> Result<&'a mut T, MaxSizeReached>Ensures a value is in the entry by inserting the result of the default function if empty.
The default function is not called if the entry exists in the map. Returns a mutable reference to the first value in the entry.
Examples
Basic usage.
# use HeaderMap; let mut map = new; let res = map.entry .or_insert_with; assert_eq!;The default function is not called if the entry exists in the map.
# use HeaderMap; # use HOST; let mut map = new; map.try_insert.unwrap; let res = map.try_entry .unwrap .or_try_insert_with .unwrap; assert_eq!;fn key(self: &Self) -> &HeaderNameReturns a reference to the entry's key
Examples
# use HeaderMap; let mut map = new; assert_eq!;
impl<'a, T> Freeze for Entry<'a, T>
impl<'a, T> RefUnwindSafe for Entry<'a, T>
impl<'a, T> Send for Entry<'a, T>
impl<'a, T> Sync for Entry<'a, T>
impl<'a, T> Unpin for Entry<'a, T>
impl<'a, T> UnsafeUnpin for Entry<'a, T>
impl<'a, T> UnwindSafe for Entry<'a, T>
impl<'a, T: $crate::fmt::Debug + 'a> Debug for Entry<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Entry<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Entry<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Entry<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Entry<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Entry<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Entry<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Entry<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>