Struct GetAll

struct GetAll<'a, T> { ... }

A view to all values stored in a single entry.

This struct is returned by HeaderMap::get_all.

Implementations

impl<'a, T: 'a> GetAll<'a, T>

fn iter(self: &Self) -> ValueIter<'a, T>

Returns an iterator visiting all values associated with the entry.

Values are iterated in insertion order.

Examples

# use http::HeaderMap;
# use http::header::HOST;
let mut map = HeaderMap::new();
map.insert(HOST, "hello.world".parse().unwrap());
map.append(HOST, "hello.earth".parse().unwrap());

let values = map.get_all("host");
let mut iter = values.iter();
assert_eq!(&"hello.world", iter.next().unwrap());
assert_eq!(&"hello.earth", iter.next().unwrap());
assert!(iter.next().is_none());

impl<'a, T> Freeze for GetAll<'a, T>

impl<'a, T> IntoIterator for GetAll<'a, T>

fn into_iter(self: Self) -> ValueIter<'a, T>

impl<'a, T> RefUnwindSafe for GetAll<'a, T>

impl<'a, T> Send for GetAll<'a, T>

impl<'a, T> Sync for GetAll<'a, T>

impl<'a, T> Unpin for GetAll<'a, T>

impl<'a, T> UnsafeUnpin for GetAll<'a, T>

impl<'a, T> UnwindSafe for GetAll<'a, T>

impl<'a, T: $crate::fmt::Debug> Debug for GetAll<'a, T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a, T: PartialEq> PartialEq for GetAll<'a, T>

fn eq(self: &Self, other: &Self) -> bool

impl<T> Any for GetAll<'a, T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GetAll<'a, T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GetAll<'a, T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for GetAll<'a, T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for GetAll<'a, T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GetAll<'a, T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GetAll<'a, T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>