Struct Keys
struct Keys<'a, T> { ... }
An iterator over HeaderMap keys.
Each header name is yielded only once, even if it has more than one associated value.
Implementations
impl<'a, T> ExactSizeIterator for Keys<'a, T>
impl<'a, T> Freeze for Keys<'a, T>
impl<'a, T> FusedIterator for Keys<'a, T>
impl<'a, T> Iterator for Keys<'a, T>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn count(self: Self) -> usizefn last(self: Self) -> Option<<Self as >::Item>
impl<'a, T> RefUnwindSafe for Keys<'a, T>
impl<'a, T> Send for Keys<'a, T>
impl<'a, T> Sync for Keys<'a, T>
impl<'a, T> Unpin for Keys<'a, T>
impl<'a, T> UnsafeUnpin for Keys<'a, T>
impl<'a, T> UnwindSafe for Keys<'a, T>
impl<'a, T: $crate::fmt::Debug> Debug for Keys<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I> IntoIterator for Keys<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for Keys<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Keys<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Keys<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Keys<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Keys<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Keys<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Keys<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>