Struct OccupiedEntry
struct OccupiedEntry<'a, T> { ... }
A view into a single occupied location in a HeaderMap.
This struct is returned as part of the Entry enum.
Implementations
impl<'a, T> OccupiedEntry<'a, T>
fn key(self: &Self) -> &HeaderNameReturns a reference to the entry's key.
Examples
# use ; let mut map = new; map.insert; if let Occupied = map.entryfn get(self: &Self) -> &TGet a reference to the first value in the entry.
Values are stored in insertion order.
Panics
getpanics if there are no values associated with the entry.Examples
# use ; let mut map = new; map.insert; if let Occupied = map.entryfn get_mut(self: &mut Self) -> &mut TGet a mutable reference to the first value in the entry.
Values are stored in insertion order.
Panics
get_mutpanics if there are no values associated with the entry.Examples
# use ; let mut map = default; map.insert; if let Occupied = map.entryfn into_mut(self: Self) -> &'a mut TConverts the
OccupiedEntryinto a mutable reference to the first value.The lifetime of the returned reference is bound to the original map.
Panics
into_mutpanics if there are no values associated with the entry.Examples
# use ; let mut map = default; map.insert; map.append; if let Occupied = map.entry assert_eq!;fn insert(self: &mut Self, value: T) -> TSets the value of the entry.
All previous values associated with the entry are removed and the first one is returned. See
insert_multfor an API that returns all values.Examples
# use ; let mut map = new; map.insert; if let Occupied = map.entry assert_eq!;fn insert_mult(self: &mut Self, value: T) -> ValueDrain<'_, T>Sets the value of the entry.
This function does the same as
insertexcept it returns an iterator that yields all values previously associated with the key.Examples
# use ; let mut map = new; map.insert; map.append; if let Occupied = map.entry assert_eq!;fn append(self: &mut Self, value: T)Insert the value into the entry.
The new value is appended to the end of the entry's value list. All previous values associated with the entry are retained.
Examples
# use ; let mut map = new; map.insert; if let Occupied = map.entry let values = map.get_all; let mut i = values.iter; assert_eq!; assert_eq!;fn remove(self: Self) -> TRemove the entry from the map.
All values associated with the entry are removed and the first one is returned. See
remove_entry_multfor an API that returns all values.Examples
# use ; let mut map = new; map.insert; if let Occupied = map.entry assert!;fn remove_entry(self: Self) -> (HeaderName, T)Remove the entry from the map.
The key and all values associated with the entry are removed and the first one is returned. See
remove_entry_multfor an API that returns all values.Examples
# use ; let mut map = new; map.insert; if let Occupied = map.entry assert!;fn remove_entry_mult(self: Self) -> (HeaderName, ValueDrain<'a, T>)Remove the entry from the map.
The key and all values associated with the entry are removed and returned.
fn iter(self: &Self) -> ValueIter<'_, T>Returns an iterator visiting all values associated with the entry.
Values are iterated in insertion order.
Examples
# use ; let mut map = new; map.insert; map.append; if let Occupied = map.entryfn iter_mut(self: &mut Self) -> ValueIterMut<'_, T>Returns an iterator mutably visiting all values associated with the entry.
Values are iterated in insertion order.
Examples
# use ; let mut map = default; map.insert; map.append; if let Occupied = map.entry let mut values = map.get_all; let mut i = values.iter; assert_eq!; assert_eq!;
impl<'a, T> Freeze for OccupiedEntry<'a, T>
impl<'a, T> IntoIterator for OccupiedEntry<'a, T>
fn into_iter(self: Self) -> ValueIterMut<'a, T>
impl<'a, T> RefUnwindSafe for OccupiedEntry<'a, T>
impl<'a, T> Send for OccupiedEntry<'a, T>
impl<'a, T> Sync for OccupiedEntry<'a, T>
impl<'a, T> Unpin for OccupiedEntry<'a, T>
impl<'a, T> UnsafeUnpin for OccupiedEntry<'a, T>
impl<'a, T> UnwindSafe for OccupiedEntry<'a, T>
impl<'a, T: $crate::fmt::Debug> Debug for OccupiedEntry<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for OccupiedEntry<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for OccupiedEntry<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for OccupiedEntry<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for OccupiedEntry<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for OccupiedEntry<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for OccupiedEntry<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for OccupiedEntry<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>