Struct ToStrError
struct ToStrError { ... }
A possible error when converting a HeaderValue to a string representation.
Header field values may contain opaque bytes, in which case it is not possible to represent the value as a string.
Implementations
impl Debug for ToStrError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ToStrError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for ToStrError
impl Freeze for ToStrError
impl RefUnwindSafe for ToStrError
impl Send for ToStrError
impl Sync for ToStrError
impl Unpin for ToStrError
impl UnsafeUnpin for ToStrError
impl UnwindSafe for ToStrError
impl<T> Any for ToStrError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ToStrError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ToStrError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ToStrError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for ToStrError
fn to_string(self: &Self) -> String
impl<T, U> Into for ToStrError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ToStrError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ToStrError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>