Struct Error

struct Error { ... }

A generic "error" for HTTP connections

This error type is less specific than the error returned from other functions in this crate, but all other errors can be converted to this error. Consumers of this crate can typically consume and work with this form of error for conversions with the ? operator.

Implementations

impl Error

fn is<T: error::Error + 'static>(self: &Self) -> bool

Return true if the underlying error has the same type as T.

fn get_ref(self: &Self) -> &dyn Error + 'static

Return a reference to the lower level, inner error.

impl Debug for Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for Error

fn source(self: &Self) -> Option<&dyn Error + 'static>

impl Freeze for Error

impl From for Error

fn from(err: Infallible) -> Error

impl From for Error

fn from(err: InvalidStatusCode) -> Error

impl From for Error

fn from(err: InvalidHeaderValue) -> Error

impl From for Error

fn from(err: MaxSizeReached) -> Error

impl From for Error

fn from(err: InvalidUriParts) -> Error

impl From for Error

fn from(err: InvalidHeaderName) -> Error

impl From for Error

fn from(err: InvalidUri) -> Error

impl From for Error

fn from(err: InvalidMethod) -> Error

impl RefUnwindSafe for Error

impl Send for Error

impl Sync for Error

impl Unpin for Error

impl UnsafeUnpin for Error

impl UnwindSafe for Error

impl<T> Any for Error

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Error

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Error

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Error

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for Error

fn to_string(self: &Self) -> String

impl<T, U> Into for Error

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Error

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Error

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>